@@ -2,6 +2,8 @@
 function (data, dvname='DV', group=NULL, model=NULL, include.all=FALSE,...) 
 {
   plots <-list()
+  value <- NULL # prevent warning from R CMD check
+  variable <- NULL # prevent warning from R CMD check
   if(is.null(group))data$grpnames <- 'all'
   if(is.null(group))group <- 'grpnames'
   if(length(unique(data[[group]])) > 1 & include.all) plots <- diagnosticPlots(
@@ -12,41 +14,24 @@ function (data, dvname='DV', group=NULL, model=NULL, include.all=FALSE,...)
 	include.all=FALSE,
 	...
   )
-  obsvar <- intersect(c("PRED","IPRE","IPRED"),names(data))
+  preds <- c('PRED','NPRED','CPRED','CPREDI','EPRED','IPRE','IPRED')
+  obsvar <- intersect(preds,names(data))
   obsid <- c("DV","grpnames")
   observed <- list()
-  if(length(obsvar) & length(obsid)){
-  	  observed <- melt(data,measure.var=obsvar,id.var=obsid)
-  	  observed$variable <- factor(
-  	  	observed$variable,
-  	  	levels=obsvar,
-  	  	labels=map(
-  	  		obsvar,
-  	  		from=c("PRED","IPRE","IPRED"),
-  	  		to=c('population','individual','individual')
-  	  	)
-#  	  	labels=c("population","individual")[c("PRED","IPRE") %in% substr(names(data),1,4)]#IPRED in NM7
-  	  )
-  }
-  resvar <- intersect(c("RES","WRES","CWRES"),names(data))
+  if(length(obsvar) & length(obsid))observed <- melt(data,measure.var=obsvar,id.var=obsid)
+  res <- c('RES','NRES','NWRES','CRES','CWRES','RESI','WRESI','CRESI','CWRESI','ERES','EWRES','ECWRES')
+  resvar <- intersect(res,names(data))
   resid <- intersect(c("PRED","TIME","grpnames","TAD"),names(data))
   res <- list()
-  if(length(resvar) & length(resid)){
-  	  res <- melt(data,measure.var=resvar,id.var=resid)
-  }
-  groupSubtitle <- function(grp){
-  	#if(grp[[1]] == "plotrGroup")return(NULL)
-  	paste("for",paste(grp,collapse=", "),"data")
-  }
+  if(length(resvar) & length(resid))res <- melt(data,measure.var=resvar,id.var=resid)
+  groupSubtitle <- function(grp)paste("for",paste(grp,collapse=", "),"data")
   #Observed vs. Predicted 
-  if(length(observed)) for (group in unique(observed$grpnames))plots[[paste('obsPred',group)]] <- xyplot(
+  if(length(observed))if('DV' %in% names(observed)) for (group in unique(observed$grpnames))plots[[paste('obsPred',group)]] <- xyplot(
 	DV ~ value |  variable, 
 	observed[observed$grpnames==group,],
 	as.table=TRUE,
 	aspect=1,
 	layout=c(2,2),
-	#xlim = with(data[data$grpames==group,],c(min(0, DV, PRED), max(0, DV, PRED))),
-	#ylim = with(data[data$grpnames==group,],c(min(0, DV, PRED), max(0, DV, PRED))),
 	ylab = paste("Observed", dvname), 
 	xlab = paste("Predicted", dvname),
 	panel= function(x,y,...){
@@ -56,19 +41,20 @@ function (data, dvname='DV', group=NULL, model=NULL, include.all=FALSE,...)
 	main=paste(model,"\nObserved vs. Predicted",groupSubtitle(group)),
 	...
    )
+   h0loess <- function(x,y,lty=1,...){
+  		panel.xyplot(x,y,lty=lty,...)
+  		panel.abline(h=0,lty=lty,)
+  		panel.loess(x,y,lty=2,...)
+  }
    #Residuals vs. Predicted
-   if(length(res))for (group in unique(res$grpnames)) plots[[paste('resPred',group)]] <- xyplot(
+   if(length(res))if('PRED' %in% names(res))for (group in unique(res$grpnames)) plots[[paste('resPred',group)]] <- xyplot(
   	value ~ PRED |  variable, 
   	res[res$grpnames==group,],
   	as.table=TRUE,
   	layout=c(2,2),
   	ylab = "residuals", 
   	xlab = paste("Predicted", dvname),
-  	panel= function(x,y,lty=1,...){
-  		panel.xyplot(x,y,lty=lty,...)
-  		panel.abline(h=0,lty=lty,)
-  		panel.loess(x,y,lty=2,...)
-  	},
+  	panel= h0loess,
   	scales=list(y=list(relation="free")),
   	main=paste(model,"\nResiduals vs. Predicted",groupSubtitle(group)),
 	...
@@ -81,11 +67,7 @@ function (data, dvname='DV', group=NULL, model=NULL, include.all=FALSE,...)
   	layout=c(2,2),
   	ylab = "residuals", 
   	xlab = paste("Time (hr)"),
-  	panel= function(x,y,lty=1,...){
-  		panel.xyplot(x,y,lty=lty,...)
-  		panel.abline(h=0,lty=lty,)
-  		panel.loess(x,y,lty=2,...)
-  	},
+  	panel= h0loess,
   	scales=list(y=list(relation="free")),
   	main=paste(model,"\nResiduals vs. Time",groupSubtitle(group)),
 	...
@@ -98,11 +80,7 @@ function (data, dvname='DV', group=NULL, model=NULL, include.all=FALSE,...)
   	layout=c(2,2),
   	ylab = "residuals", 
   	xlab = paste("Time (hr)"),
-  	panel= function(x,y,lty=1,...){
-  		panel.xyplot(x,y,lty=lty,...)
-  		panel.abline(h=0,lty=lty,)
-  		panel.loess(x,y,lty=2,...)
-  	},
+  	panel= h0loess,
   	scales=list(y=list(relation="free")),
   	main=paste(model,"\nResiduals vs. TAD",groupSubtitle(group)),
 	...
@@ -125,29 +103,6 @@ function (data, dvname='DV', group=NULL, model=NULL, include.all=FALSE,...)
 	qtype=7,
 	...
   )
-  #QQ-Res
-  if(length(res))if(all(c("WRES","CWRES") %in% resvar))for (group in unique(res$grpnames))plots[[paste('resCwresQ',group)]] <- qq(
-  	variable ~ value ,
-  	res[res$grpnames==group,],
-  	as.table=TRUE,
-  	layout=c(2,2),
-  	aspect=1,
-  	subset=res$variable[res$grpnames==group] %in% c("WRES","CWRES"),
-  	panel = function(...) {
-    	panel.qq(...)
-    	panel.abline(0,1)
-    },
-  	main=paste(model,"\nQ-Q Plot of CWRES vs. WRES",groupSubtitle(group)),
-	...
-  )
-  #Residuals
-  if(length(res))for (group in unique(res$grpnames))plots[[paste('plotsRes',group)]] <- bwplot(
-  	value ~ variable,
-  	res[res$grpnames==group,],
-  	main=paste(model,"Boxplots of Residuals",groupSubtitle(group)),
-  	ylab="residuals",
-	...
-  )
   plots
 }
 
